pitchtools.HarmonicCounterpointIntervalClass
============================================

.. autoclass:: abjad.tools.pitchtools.HarmonicCounterpointIntervalClass
   :members:
   :undoc-members:
   :show-inheritance:
